# 2022-08-22 - Liquidity Gauge Factory V2

Deployment of the `LiquidityGaugeFactory`, for liquidity gauges to be used with pools on mainnet. This updated version includes caps on the relative weight (allocated emissions) for each gauge.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`LiquidityGaugeV5` artifact](./artifact/LiquidityGaugeV5.json)
- [`LiquidityGaugeFactory` artifact](./artifact/LiquidityGaugeFactory.json)
